@@ -23,7 +23,7 @@
 import os
 from datetime import datetime
 from pathlib import Path
-from typing import TYPE_CHECKING, Any, Dict, List, Union
+from typing import TYPE_CHECKING, Any, Dict, List, Set, Union
 
 import cloudpickle as pickle
 import yaml
@@ -439,11 +439,13 @@ Node Outputs
 
         import pkg_resources
 
-        dispatch_function = (
-            f"# File created by Covalent using covalent version {pkg_resources.get_distribution('cova').version}\n"
-            f"# Note that this file does not contain any global imports you did in your original dispatch\n"
-            f"# Covalent result -"
-        )
+        dispatch_function = f"# File created by Covalent using version {pkg_resources.get_distribution('cova').version}\n"
+        dispatch_function += f"# Dispatch ID: {self.dispatch_id}\n"
+        dispatch_function += f"# Workflow status: {self.status}\n"
+        dispatch_function += f"# Workflow start time: {self.start_time}\n"
+        dispatch_function += f"# Workflow end time: {self.end_time}" + "\n"
+
+        dispatch_function += "# Covalent result -"
         result_string_lines = str(self.result).split("\n")
         if len(result_string_lines) == 1:
             dispatch_function += f" {self.result}\n\n"
@@ -453,6 +455,9 @@ Node Outputs
                 dispatch_function += f"# {line}\n"
             dispatch_function += "\n"
 
+        # add imports
+        dispatch_function += self.lattice.lattice_imports + "\n" * 2
+
         directory = directory or self.results_dir
         result_folder_path = os.path.join(directory, f"{self.dispatch_id}")
         Path(result_folder_path).mkdir(parents=True, exist_ok=True)
@@ -467,9 +472,14 @@ Node Outputs
                 ).get_deserialized()
                 if function is not None and function.__name__ not in functions_added:
 
-                    dispatch_function += self.lattice.transport_graph.get_node_value(
+                    function_str = self.lattice.transport_graph.get_node_value(
                         nodes, value_key="function_string"
                     )
+                    function_str = _filter_cova_decorators(
+                        function_str,
+                        self.lattice.cova_imports,
+                    )
+                    dispatch_function += function_str
                     functions_added.append(function.__name__)
 
         lattice_function_str = convert_to_lattice_function_call(
@@ -477,7 +487,45 @@ Node Outputs
             self.lattice.workflow_function.__name__,
             self.inputs,
         )
+        lattice_function_str = _filter_cova_decorators(
+            lattice_function_str,
+            self.lattice.cova_imports,
+        )
         dispatch_function += lattice_function_str
 
         with open(os.path.join(result_folder_path, "dispatch_source.py"), "w") as f:
             f.write(dispatch_function)
+
+
+def _filter_cova_decorators(function_string: str, cova_imports: Set[str]) -> str:
+    """
+    Given a string representing a function, comment out any Covalent-related decorators.
+
+    Args
+        function_string: A string representation of a workflow function.
+
+    Returns:
+        The function string with Covalent-related decorators commented out.
+    """
+
+    has_cova_decorator = False
+    in_decorator = 0
+    function_lines = function_string.split("\n")
+    for i in range(len(function_lines)):
+        line = function_lines[i].strip()
+        if in_decorator > 0:
+            function_lines[i] = f"# {function_lines[i]}"
+            in_decorator += line.count("(")
+            in_decorator -= line.count(")")
+        elif line.startswith("@"):
+            decorator_name = line.split("@")[1].split(".")[0].split("(")[0]
+            if decorator_name in cova_imports:
+                function_lines[i] = f"# {function_lines[i]}"
+                has_cova_decorator = True
+                in_decorator += line.count("(")
+                in_decorator -= line.count(")")
+
+    if has_cova_decorator:
+        return "\n".join(function_lines)
+    else:
+        return function_string
